@@ -79,6 +79,11 @@
 #' )
 #' irmi(sleep,modelFormulas=form,trace=TRUE)
 #' 
+#' # Example with ordered variable
+#' td <- testdata$wna
+#' td$c1 <- as.ordered(td$c1)
+#' irmi(td)
+#' 
 #' @export irmi
 #' @S3method irmi data.frame
 #' @S3method irmi survey.design
@@ -179,15 +184,15 @@ irmi.default <- function(x, eps=5, maxit=100, mixed=NULL,mixed.constant=NULL, co
   }
   class1 <- function(x) class(x)[1] 
   types <- lapply(x,class1)
-  if(any(types=="ordered")){
-    for(i in which(types=="ordered")){
-      msg <- paste(names(x)[i]," is defined as ordered,but irmi cannot deal with ordered variables
-              at the moment, therefore the ordered attribute is set to FALSE \n",sep="")
-      cat(msg)
-      x[,i] <- factor(x[,i],ordered=FALSE)
-      types[i] <- "factor"
-    }
-  }
+#  if(any(types=="ordered")){
+#    for(i in which(types=="ordered")){
+#      msg <- paste(names(x)[i]," is defined as ordered,but irmi cannot deal with ordered variables
+#              at the moment, therefore the ordered attribute is set to FALSE \n",sep="")
+#      cat(msg)
+#      x[,i] <- factor(x[,i],ordered=FALSE)
+#      types[i] <- "factor"
+#    }
+#  }
   types[colnames(x)%in%mixed] <- "mixed"
   types[colnames(x)%in%count] <- "count"
   
@@ -201,13 +206,18 @@ irmi.default <- function(x, eps=5, maxit=100, mixed=NULL,mixed.constant=NULL, co
       types[ind] <- "factor"
     }
   }
-  indFac <- which(types=="factor")
+  
+  #determine factor type: dichotomous or polytomous
+  #detect problematic factors
+  indFac <- which(types == "factor")
   for(ind in indFac){
-    if(length(levels(x[,ind]))==2)
+    #get number of levels
+    fac_nlevels = nlevels(x[[ind]])
+    if (fac_nlevels == 2)
       types[ind] <- "binary"
-    else if(length(levels(x[,ind]))>2)
+    else if (fac_nlevels > 2)
       types[ind] <- "nominal"
-    else stop("factor with less than 2 levels detected!")
+    else stop(sprintf("factor with less than 2 levels detected! - `%s`", names(x)[ind]))
   }
   missingSummary <- cbind(types,apply(x,2,function(x)sum(is.na(x))))
   colnames(missingSummary) <- c("type","#missing")
@@ -355,7 +365,9 @@ irmi.default <- function(x, eps=5, maxit=100, mixed=NULL,mixed.constant=NULL, co
       
       #print(attributes(dataForReg$y)$cn)
       
-      
+      if(trace){
+        print(types[[i]])
+      }
       if( types[i]=="integer"||types[i]=="numeric" || types[i] =="mixed"){ ## todo: ausserhalb der Schleife!!
         meth = "numeric" 
       } else if( types[i]=="binary" ){ 
@@ -364,6 +376,8 @@ irmi.default <- function(x, eps=5, maxit=100, mixed=NULL,mixed.constant=NULL, co
         meth = "factor" 
       } else if( types[i]=="count"){
         meth = "count"
+      }else if( types[i]=="ordered" ){ 
+        meth = "ordered" 
       }
       
       ## replace initialised missings:
@@ -465,6 +479,8 @@ irmi.default <- function(x, eps=5, maxit=100, mixed=NULL,mixed.constant=NULL, co
         meth = "factor" 
       } else if( types[i]=="count"){
         meth = "count"
+      } else if( types[i]=="ordered"){
+        meth = "ordered"
       }
       if(!is.null(modelFormulas)){
         TFform <- names(modelFormulas)==colnames(x)[i]
@@ -631,7 +647,8 @@ getM <- function(xReg, ndata, type, index,mixedTF,mixedConstant,factors,step,rob
       numeric = useLM(xReg, ndata, index,mixedTF,mixedConstant,factors,step,robust,noise,noise.factor,force,robMethod,form=form),
       factor  = useMN(xReg, ndata, index,factors,step,robust,form=form,multinom.method=multinom.method),
       bin     = useB(xReg, ndata, index,factors,step,robust,form=form),
-      count   = useGLMcount(xReg, ndata, index, factors, step, robust,form=form)
+      count   = useGLMcount(xReg, ndata, index, factors, step, robust,form=form),
+      ordered  = useOrd(xReg, ndata, index,factors,step,robust,form=form),
   )
 }
 
@@ -834,11 +851,36 @@ useMN <- function(xReg, ndata,  wy, factors, step, robust,form,multinom.method){
     }
     imp <- predict(multimod, newdata=ndata)
   }else{
-   stop("multinom is the only implemented method at the moment!\n") 
+    stop("multinom is the only implemented method at the moment!\n") 
   }
   return(imp)
 }
 
+
+# ordered response
+useOrd <- function(xReg, ndata,  wy, factors, step, robust,form){
+  factors <- Inter(list(colnames(xReg),factors))
+  if(length(factors)>0){
+    for(f in 1:length(factors)){
+      if(any(summary(xReg[,factors[f]])==0)){
+        xReg <- xReg[,-which(colnames(xReg)==factors[f])]
+        ndata <- ndata[,-which(colnames(ndata)==factors[f])]
+      }
+    }
+  }
+  form <- form[form%in%names(xReg)]
+  if(length(form)>0)
+    form <- as.formula(paste("y ~",paste(form,collapse="+")))
+  else
+    form <- y~.
+  co <- capture.output(multimod <- polr(form, data=xReg))
+  if(step){
+    multimod <- stepAIC(multimod,xReg)
+  }
+  imp <- predict(multimod, newdata=ndata)
+  return(imp)
+}
+
 # binary response
 useB <- function(xReg,  ndata, wy,factors,step,robust,form){
   factors <- Inter(list(colnames(xReg),factors))
@@ -881,5 +923,4 @@ useB <- function(xReg,  ndata, wy,factors,step,robust,form){
   imp[imp >= 0.5] <- 1
 #    library(VGAM, warn.conflicts = FALSE, verbose=FALSE)
   return(imp)
-}
-
+}
\ No newline at end of file
